package com.ruixuan.live.mapper;

import com.alibaba.fastjson.JSONObject;
import com.ruixuan.live.entity.KuaishouLiveUserAccountPart;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 快手账户协作人群Mapper接口
 *
 * @author ruoyi
 * @date 2022-05-31
 */
public interface KuaishouLiveUserAccountPartMapper {
    /**
     * 查询快手账户协作人群
     *
     * @param id 快手账户协作人群主键
     * @return 快手账户协作人群
     */
    List<KuaishouLiveUserAccountPart> selectKuaishouLiveUserAccountPartById(Long ksId);

    /**
     * 删除快手账户协作人群
     *
     * @param id 快手账户协作人群主键
     * @return 结果
     */
    public int deleteKuaishouLiveUserAccountPartById(Long ksId);

    /**
     * 删除快手账户协作人群
     *
     * @param id 快手账户协作人群主键
     * @return 结果
     */
    public int deleteByAccountId(@Param("ksId") Long ksId, @Param("accountId") Long accountId,@Param("userId") Long userId);


    void replaceBatch(@Param(value = "collaborators") List<JSONObject> collaborators);

    List<JSONObject> queryCollaboratorsById(@Param("ksId") Long ksId, @Param("accountId") Long accountId);

    List<JSONObject> queryAccountCollaborators(@Param("ksId") Long ksId, @Param("accountId") Long accountId);
}
